summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/tools/wasm-split/instrumenter.cpp26
1 files changed, 14 insertions, 12 deletions
diff --git a/src/tools/wasm-split/instrumenter.cpp b/src/tools/wasm-split/instrumenter.cpp
index 36875bfc0..c23a70f06 100644
--- a/src/tools/wasm-split/instrumenter.cpp
+++ b/src/tools/wasm-split/instrumenter.cpp
@@ -266,19 +266,21 @@ void Instrumenter::addProfileExport() {
}
}
- // Export the memory if it is not already exported.
- bool memoryExported = false;
- for (auto& ex : wasm->exports) {
- if (ex->kind == ExternalKind::Memory) {
- memoryExported = true;
- break;
+ // Export the memory if it is not already exported or imported.
+ if (!wasm->memory.imported()) {
+ bool memoryExported = false;
+ for (auto& ex : wasm->exports) {
+ if (ex->kind == ExternalKind::Memory) {
+ memoryExported = true;
+ break;
+ }
+ }
+ if (!memoryExported) {
+ wasm->addExport(
+ Builder::makeExport("profile-memory",
+ Names::getValidExportName(*wasm, wasm->memory.name),
+ ExternalKind::Memory));
}
- }
- if (!memoryExported) {
- wasm->addExport(
- Builder::makeExport("profile-memory",
- Names::getValidExportName(*wasm, wasm->memory.name),
- ExternalKind::Memory));
}
}